@@ -14,6 +14,12 @@ begin
 rescue LoadError
 end
 
+RSpec.configure do |c|
+  c.add_setting :enable_pathname_stubbing, :default => false
+end
+
+require 'rspec-puppet/monkey_patches'
+
 RSpec.configure do |c|
   c.add_setting :environmentpath, :default => '/etc/puppetlabs/code/environments'
   c.add_setting :module_path, :default => nil
@@ -23,6 +29,8 @@ RSpec.configure do |c|
   c.add_setting :config, :default => nil
   c.add_setting :confdir, :default => '/etc/puppet'
   c.add_setting :default_facts, :default => {}
+  c.add_setting :default_node_params, :default => {}
+  c.add_setting :default_trusted_facts, :default => {}
   c.add_setting :hiera_config, :default => '/dev/null'
   c.add_setting :parser, :default => 'current'
   c.add_setting :trusted_node_data, :default => false
@@ -31,6 +39,10 @@ RSpec.configure do |c|
   c.add_setting :strict_variables, :default => false
   c.add_setting :adapter
 
+  c.before(:all) do
+    RSpec::Puppet::Setup.safe_setup_directories(nil, false)
+  end
+
   if defined?(Puppet::Test::TestHelper)
     begin
       Puppet::Test::TestHelper.initialize
@@ -55,6 +67,8 @@ RSpec.configure do |c|
     c.before :each do
       begin
         Puppet::Test::TestHelper.before_each_test
+      rescue Puppet::Context::DuplicateRollbackMarkError
+        Puppet::Test::TestHelper.send(:initialize_settings_before_each)
       rescue
       end
     end
@@ -74,4 +88,8 @@ RSpec.configure do |c|
       c.adapter = adapter
     end
   end
+
+  c.before :each do |example|
+    stub_file_consts(example) if self.respond_to?(:stub_file_consts)
+  end
 end
