@@ -1,3 +1,14 @@
+unless defined?(RSpec::Core::NullReporter)
+  module RSpec::Core
+    class NullReporter
+      def self.method_missing(*)
+        # ignore
+      end
+      private_class_method :method_missing
+    end
+  end
+end
+
 module RSpec::Puppet
   class Coverage
 
@@ -6,7 +17,8 @@ module RSpec::Puppet
     class << self
       extend Forwardable
       def_delegators(:instance, :add, :cover!, :report!,
-                     :filters, :add_filter, :add_from_catalog)
+                     :filters, :add_filter, :add_from_catalog,
+                     :results)
 
       attr_writer :instance
 
@@ -17,7 +29,7 @@ module RSpec::Puppet
 
     def initialize
       @collection = {}
-      @filters = ['Stage[main]', 'Class[Settings]', 'Class[main]']
+      @filters = ['Stage[main]', 'Class[Settings]', 'Class[main]', 'Node[default]']
     end
 
     def add(resource)
@@ -27,12 +39,21 @@ module RSpec::Puppet
     end
 
     def add_filter(type, title)
-      @filters << "#{type.capitalize}[#{title.capitalize}]"
+      def capitalize_name(name)
+        name.split('::').map { |subtitle| subtitle.capitalize }.join('::')
+      end
+
+      type = capitalize_name(type)
+      if type == 'Class'
+        title = capitalize_name(title)
+      end
+
+      @filters << "#{type}[#{title}]"
     end
 
     # add all resources from catalog declared in module test_module
     def add_from_catalog(catalog, test_module)
-      coverable_resources = catalog.to_a.select { |resource| !filter_resource?(resource, test_module) }
+      coverable_resources = catalog.to_a.reject { |resource| !test_module.nil? && filter_resource?(resource, test_module) }
       coverable_resources.each do |resource|
         add(resource)
       end
@@ -82,8 +103,12 @@ module RSpec::Puppet
         coverage_results = coverage_test.example("Must be at least #{coverage_desired}% of code coverage") {
           expect( coverage_actual.to_f ).to be >= coverage_desired.to_f
         }
-        coverage_test.run
-        passed = coverage_results.execution_result.status == :passed
+        coverage_test.run(RSpec::Core::NullReporter)
+        passed = if coverage_results.execution_result.respond_to? :status then
+                   coverage_results.execution_result.status == :passed
+                 else
+                   coverage_results.execution_result[:status] == 'passed'
+                 end
 
         RSpec.configuration.reporter.example_failed coverage_results unless passed
       else
